Mopidy-InternetArchive
========================================================================

Mopidy-InternetArchive is a Mopidy_ extension for playing music and
audio from the `Internet Archive`_.


Installation
------------------------------------------------------------------------

Like other Mopidy extensions, Mopidy-InternetArchive can be installed
using pip by running::

    pip install Mopidy-InternetArchive

You can also download and install Debian/Ubuntu packages for
Mopidy-InternetArchive releases_.


Project Resources
------------------------------------------------------------------------

- `Documentation`_
- `Issue Tracker`_
- `Source Code`_
- `Change Log`_

.. image:: https://pypip.in/v/Mopidy-InternetArchive/badge.png
    :target: https://pypi.python.org/pypi/Mopidy-InternetArchive/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Mopidy-InternetArchive/badge.png
    :target: https://pypi.python.org/pypi/Mopidy-InternetArchive/
    :alt: Number of PyPI downloads


License
------------------------------------------------------------------------

Mopidy-InternetArchive is Copyright 2014 Thomas Kemmer.

Licensed under the `Apache License, Version 2.0`_.


.. _Mopidy: http://www.mopidy.com/
.. _Internet Archive: http://archive.org
.. _releases: https://github.com/tkem/mopidy-internetarchive/releases
.. _Documentation: http://mopidy-internetarchive.readthedocs.org/en/docs/
.. _Issue Tracker: https://github.com/tkem/mopidy-internetarchive/issues/
.. _Source Code: https://github.com/tkem/mopidy-internetarchive
.. _Change Log: https://github.com/tkem/mopidy-internetarchive/blob/master/CHANGELOG.rst
.. _Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0
